# Welcome to geoapp


[![image](https://img.shields.io/pypi/v/geoapp.svg)](https://pypi.python.org/pypi/geoapp)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: <https://ginamanou.github.io/geoapp>
    

## Features

-   TODO
